@@ -14,7 +14,7 @@ import gettext
 from gi.repository import GLib
 
 try:
-    from defs import VERSION, PREFIX
+    from .defs import VERSION, PREFIX
 except ImportError:
     PREFIX = "/usr"
     VERSION = "0.0.0"
@@ -38,7 +38,7 @@ else:
     BASE_DIR        = os.path.join(root_dir, '../data')
     PUZZLE_DIR      = BASE_DIR
 
-DOMAIN = 'gnome-sudoku'
+DOMAIN = 'gnome-games'
 locale.bind_textdomain_codeset(DOMAIN, "UTF-8") # See Bug 608425
 gettext.bindtextdomain(DOMAIN, LOCALEDIR)
 gettext.textdomain(DOMAIN)
