@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import os.path
+import signal
 import threading
 
 import gi
@@ -10,19 +11,18 @@ from gettext import gettext as _
 from gettext import ngettext
 
 import cairo
-import dialog_swallower
-import game_selector
-import gsudoku
-import printing
-import saver
-import signal
-import sudoku_maker
-import timer
-import tracker_info
-from defaults import (APPNAME, APPNAME_SHORT, AUTHORS, COPYRIGHT, DESCRIPTION, DOMAIN, 
-        IMAGE_DIR, MIN_NEW_PUZZLES, UI_DIR, VERSION, WEBSITE, WEBSITE_LABEL)
-from gtk_goodies import Undo, dialog_extras
-from simple_debug import simple_debug, options
+from . import dialog_swallower
+from . import game_selector
+from . import gsudoku
+from . import printing
+from . import saver
+from . import sudoku_maker
+from . import timer
+from . import tracker_info
+from .defaults import (APPNAME, APPNAME_SHORT, AUTHORS, COPYRIGHT, DESCRIPTION, DOMAIN,
+                       IMAGE_DIR, MIN_NEW_PUZZLES, UI_DIR, VERSION, WEBSITE, WEBSITE_LABEL)
+from .gtk_goodies import Undo, dialog_extras
+from .simple_debug import simple_debug, options
 
 def inactivate_new_game_etc (fun):
     def inactivate_new_game_etc_ (ui, *args, **kwargs):
@@ -46,7 +46,7 @@ def inactivate_new_game_etc (fun):
             if not action:
                 action = ui.uimanager.get_widget(p)
             if not action:
-                print 'No action at path', p
+                print('No action at path', p)
             else:
                 action.set_sensitive(False)
         ret = fun(ui, *args, **kwargs)
@@ -55,7 +55,7 @@ def inactivate_new_game_etc (fun):
             if not action:
                 action = ui.uimanager.get_widget(p)
             if not action:
-                print 'No action at path', p
+                print('No action at path', p)
             else:
                 action.set_sensitive(True)
         return ret
@@ -257,7 +257,7 @@ class UI:
         undo_widg = self.main_actions.get_action('Undo')
         redo_widg = self.main_actions.get_action('Redo')
         self.history = Undo.UndoHistoryList(undo_widg, redo_widg)
-        for entry in self.gsd.__entries__.values():
+        for entry in list(self.gsd.__entries__.values()):
             Undo.UndoableGenericWidget(entry, self.history,
                                        set_method = 'set_value_for_undo',
                                        get_method = 'get_value_for_undo',
@@ -311,7 +311,7 @@ class UI:
 
     def setup_toggles (self):
         # sync up toggles with gsettings values...
-        map(lambda tpl: self.wrap_toggle(*tpl),
+        list(map(lambda tpl: self.wrap_toggle(*tpl),
             [('always-show-hints',
               self.main_actions.get_action('AlwaysShowPossible')),
              ('show-impossible-implications',
@@ -322,7 +322,7 @@ class UI:
               self.main_actions.get_action('ToggleHighlight')),
              ('show-tracker',
               self.main_actions.get_action('Tracker')),
-             ])
+             ]))
 
     @simple_debug
     def start_worker_thread (self, *args):
@@ -349,7 +349,7 @@ class UI:
             delattr(self, 'dancer')
 
     def start_dancer (self):
-        import dancer
+        from . import dancer
         self.dancer = dancer.GridDancer(self.gsd)
         self.dancer.start_dancing()
 
@@ -675,9 +675,9 @@ class UI:
     def show_help (self, *args):
         try:
             Gtk.show_uri(self.w.get_screen(), "help:gnome-sudoku", Gtk.get_current_event_time())
-        except GObject.GError, error:
+        except GObject.GError as error:
             # FIXME: This should create a pop-up dialog
-            print _('Unable to display help: %s') % str(error)
+            print(_('Unable to display help: %s') % str(error))
 
     @simple_debug
     def print_game (self, *args):
@@ -782,7 +782,7 @@ class TrackerBox (Gtk.VBox):
 
     @simple_debug
     def add_tracker (self, *args, **keys):
-        if keys and keys.has_key('tracker_id'):
+        if keys and 'tracker_id' in keys:
             tracker_id = self.tinfo.create_tracker(keys['tracker_id'])
         else:
             tracker_id = self.tinfo.create_tracker()
@@ -965,7 +965,7 @@ class TrackerBox (Gtk.VBox):
 
 def start_game ():
     if options.debug:
-        print 'Starting GNOME Sudoku in debug mode'
+        print('Starting GNOME Sudoku in debug mode')
 
     # Quick fix for bug #703169
     signal.signal(signal.SIGINT, signal.SIG_DFL)
@@ -988,7 +988,7 @@ def start_game ():
             u.quit_cb()
 
 def profile_me ():
-    print 'Profiling GNOME Sudoku'
+    print('Profiling GNOME Sudoku')
     import tempfile, hotshot, hotshot.stats
     pname = os.path.join(tempfile.gettempdir(), 'GNOME_SUDOKU_HOTSHOT_PROFILE')
     prof = hotshot.Profile(pname)
@@ -996,4 +996,3 @@ def profile_me ():
     stats = hotshot.stats.load(pname)
     stats.strip_dirs()
     stats.sort_stats('time', 'calls').print_stats()
-
